@@ -201,9 +201,9 @@ def __get_system():
     else:
         option.os_ = 'mac'
 
-def driver():
+def driver(*args, **kwargs):
     try:
-        dr = webdriver.Chrome(options=option)
+        dr = webdriver.Chrome(*args, **kwargs, options=option)
         print('='*36)
         print(f'\033[1;50;32m{"*"*10} driver已正常启动 {"*"*10}\033[0m')
         print('='*36)
@@ -240,7 +240,7 @@ def driver():
                     Path('chromedriver.exe').unlink(missing_ok=True)
                 else:
                     raise Exception('获取chrome版本失败，代码停止运行')
-                return webdriver.Chrome(options=option)
+                return webdriver.Chrome(*args, **kwargs, options=option)
             except Exception as e:
                 print('\033[1;50;31m更新chromedriver出错~\033[0m')
                 print(f'\033[1;50;31m{e}\033[0m')
